@@ -3,7 +3,7 @@ library.'''
 import logging
 from logging.handlers import SysLogHandler
 
-from hoover import utils
+from hoover import utils, confs
 
 class LogglyHttpHandler(logging.Handler):
     def __init__ (self, token='', inputname='', input=None, announce=False):
@@ -18,7 +18,7 @@ class LogglyHttpHandler(logging.Handler):
             except:
                 raise ValueError('This is not an HTTP input')
         self.token = token
-        self.endpoint = "https://logs.loggly.com/inputs/%s" % token
+        self.endpoint = "https://%s/inputs/%s" % (confs['proxy'], token)
         # TODO: verify we can write to the input
         if announce:
             # TODO: grab this boxes' IP, and announce logging to the input
@@ -30,7 +30,7 @@ class LogglyHttpHandler(logging.Handler):
 
 class LogglySyslogHandler(SysLogHandler):
     def __init__ (self, port=None, inputname='', input=None, announce=False,
-                  **kwargs):
+                  authorize=True, **kwargs):
         #TODO: avoid duplication with __init__ above
         if inputname:
             input = utils.get_input_by_name(inputname)
@@ -41,8 +41,12 @@ class LogglySyslogHandler(SysLogHandler):
                 self.inputname = input.name
             except:
                 raise ValueError("This doesn't look like a syslog input")
-            if port == 514:
-                utils.api_help('api/inputs/%s/add514' % input['id'])
+            if authorize:
+                if port == 514:
+                    utils.api_help('api/inputs/%s/add514' % input.id)
+                else:
+                    utils.api_help('api/inputs/%s/adddevice' % input.id,
+                                   method='POST')
         self.port = port
-        SysLogHandler.__init__(self, address=('logs.loggly.com', port),
+        SysLogHandler.__init__(self, address=(confs['proxy'], port),
                                **kwargs)
